"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkspaceComposite = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const ern_core_1 = require("ern-core");
class WorkspaceComposite {
    constructor(workspacePath) {
        this.path = workspacePath;
        this.miniappsDir = path_1.default.join(workspacePath, 'miniapps');
        this.packageJson = (0, ern_core_1.readPackageJsonSync)(workspacePath);
    }
    async getJsApiImpls() {
        // todo
        return Promise.resolve([]);
    }
    async getMiniApps() {
        const res = [];
        for (const file of await fs_extra_1.default.readdir(this.miniappsDir)) {
            const f = path_1.default.join(this.miniappsDir, file);
            if ((await fs_extra_1.default.stat(f)).isDirectory()) {
                res.push(new ern_core_1.BaseMiniApp({
                    miniAppPath: f,
                    packagePath: ern_core_1.PackagePath.fromString(f),
                }));
            }
        }
        return res;
    }
    async getResolvedNativeDependencies() {
        const nativeDependencies = await this.getNativeDependencies();
        return ern_core_1.nativeDepenciesVersionResolution.resolveNativeDependenciesVersionsEx(nativeDependencies);
    }
    async getInjectableNativeDependencies(platform) {
        const dependencies = await this.getResolvedNativeDependencies();
        const result = [];
        for (const dependency of dependencies.resolved) {
            // Always include react-native
            if (dependency.name === 'react-native') {
                result.push(dependency);
                continue;
            }
            if (platform === 'android') {
                if (await ern_core_1.manifest.getPluginConfig(dependency, 'android')) {
                    result.push(dependency);
                }
            }
            else if (await ern_core_1.manifest.getPluginConfig(dependency, 'ios')) {
                result.push(dependency);
            }
        }
        return result;
    }
    async getMiniAppsPackages() {
        const miniapps = await this.getMiniApps();
        const res = [];
        for (const miniapp of miniapps) {
            const pJson = await (0, ern_core_1.readPackageJson)(miniapp.path);
            res.push({
                name: pJson.name,
                packagePath: miniapp.packagePath,
                path: miniapp.path,
            });
        }
        return res;
    }
    async getNativeDependencies({ manifestId, } = {}) {
        if (this.cachedNativeDependencies) {
            return Promise.resolve(this.cachedNativeDependencies);
        }
        const nativeDependencies = await (0, ern_core_1.findNativeDependencies)(path_1.default.join(this.path, 'node_modules'), {
            manifestId,
        });
        // Filter out MiniApps that can be falsy considered as native dependencies
        // if developer(s) forgot to npm ignore the android/ios directory
        const miniAppsPackages = await this.getMiniAppsPackages();
        const miniAppsPaths = miniAppsPackages.map((p) => p.path);
        nativeDependencies.all = nativeDependencies.all.filter((x) => !miniAppsPaths.includes(x.basePath));
        nativeDependencies.thirdPartyNotInManifest =
            nativeDependencies.thirdPartyNotInManifest.filter((x) => !miniAppsPaths.includes(x.basePath));
        this.cachedNativeDependencies = nativeDependencies;
        return this.cachedNativeDependencies;
    }
    getReactNativeVersion() {
        return this.packageJson.dependencies['react-native'];
    }
}
exports.WorkspaceComposite = WorkspaceComposite;
//# sourceMappingURL=WorkspaceComposite.js.map