"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMetroConfig = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const js_beautify_1 = __importDefault(require("js-beautify"));
const os_1 = __importDefault(require("os"));
const ern_core_1 = require("ern-core");
async function createMetroConfig({ cwd, projectRoot, blacklistRe, extraNodeModules, watchFolders, reactNativeVersion, }) {
    return fs_extra_1.default.writeFile(path_1.default.join(cwd !== null && cwd !== void 0 ? cwd : path_1.default.resolve(), 'metro.config.js'), js_beautify_1.default.js(`const blacklist = require('${(0, ern_core_1.getMetroBlacklistPath)(reactNativeVersion)}');
module.exports = {
  ${projectRoot ? `projectRoot: "${projectRoot}",` : ''}
  ${watchFolders
        ? `watchFolders: [
        ${watchFolders
            .map((x) => `"${x.replace(/\\/g, '\\\\')}"`)
            .join(`,${os_1.default.EOL}`)}
      ],`
        : ''}
  resolver: {
    blacklistRE: blacklist([
      // Ignore IntelliJ directories
      /.*\\.idea\\/.*/,
      // ignore git directories
      /.*\\.git\\/.*/,
      // Ignore android directories
      /.*\\/app\\/build\\/.*/,
      ${blacklistRe ? blacklistRe.join(`,${os_1.default.EOL}`) : ''}
    ]),
    ${extraNodeModules
        ? `extraNodeModules: ${JSON.stringify(extraNodeModules, null, 2)},`
        : ''}
    assetExts: [
      // Image formats
      "bmp",
      "gif",
      "jpg",
      "jpeg",
      "png",
      "psd",
      "webp",
      // Video formats
      "m4v",
      "mov",
      "mp4",
      "mpeg",
      "mpg",
      "webm",
      // Audio formats
      "aac",
      "aiff",
      "caf",
      "m4a",
      "mp3",
      "wav",
      // Document formats
      "html",
      "pdf",
      // Font formats
      "otf",
      "ttf",
      // Archives (virtual files)
      "zip"
    ],
    sourceExts: ["js", "json", "ts", "tsx", "svg"],
  },
  transformer: {
    getTransformOptions: async () => ({
      transform: {
        experimentalImportSupport: false,
        inlineRequires: false,
      },
    }),
    assetPlugins: ['ern-bundle-store-metro-asset-plugin'],
    babelTransformerPath: require.resolve("react-native-svg-transformer"),
  },
};
`));
}
exports.createMetroConfig = createMetroConfig;
//# sourceMappingURL=createMetroConfig.js.map