"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.installPackagesUsingYarnLock = void 0;
const lodash_1 = __importDefault(require("lodash"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const ern_core_1 = require("ern-core");
const miniAppsDeltasUtils_1 = require("./miniAppsDeltasUtils");
async function installPackagesUsingYarnLock({ cwd, pathToYarnLock, jsPackages, }) {
    ern_core_1.shell.pushd(cwd);
    try {
        const compositePackageJson = {};
        if (lodash_1.default.some(jsPackages, (m) => !m.version)) {
            throw new Error('[generateComposite] When providing a yarn lock you cannot pass MiniApps without an explicit version');
        }
        if (!(await fs_extra_1.default.pathExists(pathToYarnLock))) {
            throw new Error(`[generateComposite] Path to yarn.lock does not exist (${pathToYarnLock})`);
        }
        ern_core_1.log.debug(`Copying yarn.lock to ${cwd}`);
        ern_core_1.shell.cp(pathToYarnLock, path_1.default.join(cwd, 'yarn.lock'));
        const yarnLock = await fs_extra_1.default.readFile(pathToYarnLock, 'utf8');
        const miniAppsDeltas = (0, miniAppsDeltasUtils_1.getMiniAppsDeltas)(jsPackages, yarnLock);
        ern_core_1.log.debug(`[generateComposite] miniAppsDeltas: ${JSON.stringify(miniAppsDeltas)}`);
        compositePackageJson.dependencies =
            (0, miniAppsDeltasUtils_1.getPackageJsonDependenciesUsingMiniAppDeltas)(miniAppsDeltas, yarnLock);
        await (0, ern_core_1.writePackageJson)(cwd, compositePackageJson);
        // Now that the composite package.json is similar to the one used to generated yarn.lock
        // we can run yarn install to get back to the exact same dependency graph as the previously
        // generated composite
        await ern_core_1.kax.task('Running yarn install').run(ern_core_1.yarn.install());
        return (0, miniAppsDeltasUtils_1.runYarnUsingMiniAppDeltas)(miniAppsDeltas);
    }
    finally {
        ern_core_1.shell.popd();
    }
}
exports.installPackagesUsingYarnLock = installPackagesUsingYarnLock;
//# sourceMappingURL=installPackagesUsingYarnLock.js.map