import { PackagePath } from 'ern-core';
/**
 * Represent the changes (deltas) in term of MiniApps versions
 * between two sets (reference and comparand)
 */
export interface MiniAppsDeltas {
    /**
     * MiniApps that are not present in the reference set but are
     * present in the comparand.
     */
    new?: PackagePath[];
    /**
     * MiniApps that are present in both sets with the same version.
     */
    same?: PackagePath[];
    /**
     * Miniapps that are present in both sets but with different versions.
     * The version of the MiniApps in this array reflects the version of
     * the comparand (i.e target upgrade verison), not the reference.
     * NOTE: The term `upgraded` is misleading here.
     */
    upgraded?: PackagePath[];
}
/**
 *  Using a yarn.lock file content as reference to figure out deltas, group the MiniApps as follow :
 * - 'new' : The MiniApp is a new one (it was not part of previously generated composite)
 * - 'same' : The MiniApp is the same (it was part of previously generated composite, with same version)
 * - 'upgraded' : The MiniApp has a new version (it was part of previously generated composite, but with a different version)
 */
export declare function getMiniAppsDeltas(miniApps: PackagePath[], yarnlock: string): MiniAppsDeltas;
/**
 * Generate package.json dependencies object based on MiniApp deltas.
 * The object will contain the same MiniApps at the same versions that were
 * used to generate the provided yarn.lock, so that we get back to original state
 * conforming with yarn.lock
 * It only contains 'same' and 'upgrade' MiniApps (not new ones)
 */
export declare function getPackageJsonDependenciesUsingMiniAppDeltas(miniAppsDeltas: MiniAppsDeltas, yarnlock: string): {
    [name: string]: string;
};
export declare function runYarnUsingMiniAppDeltas(miniAppsDeltas: MiniAppsDeltas): Promise<void>;
