"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchCompositeBabelRcRoots = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const semver_1 = __importDefault(require("semver"));
const ern_core_1 = require("ern-core");
const getNodeModuleVersion_1 = require("./getNodeModuleVersion");
const patchMetroBabelRcRoots_1 = require("./patchMetroBabelRcRoots");
async function patchCompositeBabelRcRoots({ cwd, extraPaths = [], }) {
    var _a;
    const compositePackageJson = await (0, ern_core_1.readPackageJson)(cwd);
    const compositeNodeModulesPath = path_1.default.join(cwd, 'node_modules');
    const compositeReactNativeVersion = await (0, getNodeModuleVersion_1.getNodeModuleVersion)({
        cwd,
        name: 'react-native',
    });
    const compositeMetroVersion = await (0, getNodeModuleVersion_1.getNodeModuleVersion)({
        cwd,
        name: 'metro',
    });
    const dependenciesPaths = [
        ...extraPaths,
        ...Object.keys(compositePackageJson.dependencies).map((p) => path_1.default.join(compositeNodeModulesPath, p)),
    ];
    // Any dependency that has the useBabelRc set in their package.json
    // as follow ...
    //
    // "ern": {
    //   "useBabelRc": true
    // }
    //
    // ... is added to the babelRcRoots array, so that we can properly
    // configure Babel to process the .babelrc of these dependencies.
    const babelRcRootsRe = [];
    const babelRcRootsPaths = [];
    for (const dependencyPath of dependenciesPaths) {
        if (await fs_extra_1.default.pathExists(dependencyPath)) {
            const depPackageJson = await (0, ern_core_1.readPackageJson)(dependencyPath);
            if (((_a = depPackageJson.ern) === null || _a === void 0 ? void 0 : _a.useBabelRc) === true) {
                babelRcRootsRe.push(new RegExp(`${dependencyPath}(?!.+\/)`));
                babelRcRootsPaths.push(dependencyPath);
            }
        }
    }
    await (0, patchMetroBabelRcRoots_1.patchMetroBabelRcRoots)({
        babelRcRootsRe,
        cwd,
        metroVersion: compositeMetroVersion,
        rnVersion: compositeReactNativeVersion,
    });
    // If React Native version is less than 0.56 it is still using Babel 6.
    // In that case .babelrc files will be processed in any node_modules
    // which is not a desired behavior.
    // Therefore we just remove all .babelrc from all node_modules.
    // We only keep .babelrc of node_modules that are "whitelisted",
    // as we want them to be processed.
    if (semver_1.default.lt(compositeReactNativeVersion, '0.56.0')) {
        ern_core_1.log.debug('Removing .babelrc files from all modules');
        if (babelRcRootsPaths.length > 0) {
            ern_core_1.log.debug(`Preserving .babelrc of whitelisted node_modules : ${JSON.stringify(babelRcRootsPaths, null, 2)}`);
            for (const babelRcRoot of babelRcRootsPaths) {
                ern_core_1.shell.cp(path_1.default.join(babelRcRoot, '.babelrc'), path_1.default.join(babelRcRoot, '.babelrcback'));
            }
        }
        ern_core_1.shell.rm('-rf', path_1.default.join('node_modules', '**', '.babelrc'));
        if (babelRcRootsPaths.length > 0) {
            for (const babelRcRoot of babelRcRootsPaths) {
                ern_core_1.shell.cp(path_1.default.join(babelRcRoot, '.babelrcback'), path_1.default.join(babelRcRoot, '.babelrc'));
            }
        }
    }
}
exports.patchCompositeBabelRcRoots = patchCompositeBabelRcRoots;
//# sourceMappingURL=patchCompositeBabelRcRoots.js.map