"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchMetroAssetsBug = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const ern_core_1 = require("ern-core");
// Hot apply patch from https://github.com/facebook/metro/pull/533
async function patchMetroAssetsBug({ cwd }) {
    const compositeNodeModulesPath = path_1.default.join(cwd, 'node_modules');
    const pathToFileToPatch = path_1.default.join(compositeNodeModulesPath, 'metro/src/Assets.js');
    if (!(await fs_extra_1.default.pathExists(pathToFileToPatch))) {
        return ern_core_1.log.debug(`patchMetroAssetsBug: ${pathToFileToPatch} doest not exist. Skipping patch.`);
    }
    const fileContent = await fs_extra_1.default.readFile(pathToFileToPatch, {
        encoding: 'utf8',
    });
    const firstStringToReplace = `if (path.sep === "\\\\") {`;
    const secondStringToReplace = `const absolutePath = path.resolve(projectRoot, relativePath);`;
    if (!fileContent.includes(firstStringToReplace) ||
        !fileContent.includes(secondStringToReplace)) {
        return ern_core_1.log.debug(`patchMetroAssetsBug: Cannot find strings to replace in ${pathToFileToPatch}. Skipping patch.`);
    }
    const firstReplacementString = `
// Patched by Electrode Native (patchMetroAssetsBug)
// to apply fix from https://github.com/facebook/metro/pull/533
const escapedLocalPath = localPath.replace(/\\.\\.\\//g, '__/');
assetUrlPath = path.join(publicPath, path.dirname(escapedLocalPath));
// End of Electrode Native patch
${firstStringToReplace}
`;
    const secondReplacementString = `
// Patched by Electrode Native (patchMetroAssetsBug) 
// to apply fix from https://github.com/facebook/metro/pull/533
const absolutePath = path.resolve(
  projectRoot,
  relativePath.replace(/__(\\/|\\\\)/g, '..$1'),
);
// End of Electrode Native patch
`;
    ern_core_1.log.debug(`patchMetroAssetsBug: Patching ${pathToFileToPatch}`);
    const patchedFileContent = fileContent
        .replace(firstStringToReplace, firstReplacementString)
        .replace(secondStringToReplace, secondReplacementString);
    return fs_extra_1.default.writeFile(pathToFileToPatch, patchedFileContent);
}
exports.patchMetroAssetsBug = patchMetroAssetsBug;
//# sourceMappingURL=patchMetroAssetsBug.js.map