"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.patchMetroBabelRcRoots = void 0;
const ern_core_1 = require("ern-core");
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const semver_1 = __importDefault(require("semver"));
async function patchMetroBabelRcRoots({ babelRcRootsRe, cwd, metroVersion, rnVersion, }) {
    // If React Native version is greater or equal than 0.56.0
    // it is using Babel 7
    // In that case, because we still want to process .babelrc
    // of some MiniApps that need their .babelrc to be processed
    // during bundling, we need to use the babelrcRoots option of
    // Babel 7 (https://babeljs.io/docs/en/options#babelrcroots)
    // Unfortunately, there is no way -as of metro latest version-
    // to provide this option to the metro bundler.
    // A pull request will be opened to metro to properly support
    // this option, but meanwhile, we are just directly patching the
    // metro transformer source file to make use of this option.
    // This code will be kept even when a new version of metro supporting
    // this option will be released, to keep backward compatibility.
    // It will be deprecated at some point.
    const cwdNodeModules = path_1.default.join(cwd, 'node_modules');
    const pathToFilesToPatch = [];
    if (semver_1.default.gte(rnVersion, '0.56.0') && babelRcRootsRe.length > 0) {
        if (semver_1.default.lt(metroVersion, '0.51.0')) {
            // For versions of metro < 0.51.0, we are patching the reactNativeTransformer.js file
            // https://github.com/facebook/metro/blob/v0.50.0/packages/metro/src/reactNativeTransformer.js#L120
            pathToFilesToPatch.push(path_1.default.join(cwdNodeModules, 'metro/src/reactNativeTransformer.js'));
        }
        else {
            // For versions of metro >= 0.51.0, we are patching the index.js file
            // https://github.com/facebook/metro/blob/v0.51.0/packages/metro-react-native-babel-transformer/src/index.js#L120
            const pathInCommunityCli = path_1.default.join(cwdNodeModules, '@react-native-community/cli/node_modules/metro-react-native-babel-transformer/src/index.js');
            if (await fs_extra_1.default.pathExists(pathInCommunityCli)) {
                pathToFilesToPatch.push(pathInCommunityCli);
            }
            const pathInRoot = path_1.default.join(cwdNodeModules, 'metro-react-native-babel-transformer/src/index.js');
            if (await fs_extra_1.default.pathExists(pathInRoot)) {
                pathToFilesToPatch.push(pathInRoot);
            }
        }
        for (const pathToFileToPatch of pathToFilesToPatch) {
            ern_core_1.log.debug(`[patchMetroBabelRcRoots] Patching ${pathToFileToPatch}`);
            const fileToPatch = await fs_extra_1.default.readFile(pathToFileToPatch);
            const lineToPatch = semver_1.default.lt(metroVersion, '0.64.0')
                ? `let config = Object.assign({}, babelRC, extraConfig);`
                : `const extraConfig = {`;
            // Just add extra code line to inject babelrcRoots option
            const patch = semver_1.default.lt(metroVersion, '0.64.0')
                ? `extraConfig.babelrcRoots = [
  ${babelRcRootsRe.map((b) => b.toString()).join(',')} ]
  ${lineToPatch}`
                : `${lineToPatch} babelrcRoots: [${babelRcRootsRe
                    .map((b) => b.toString())
                    .join(',')}],`;
            const patchedFile = fileToPatch.toString().replace(lineToPatch, patch);
            await fs_extra_1.default.writeFile(pathToFileToPatch, patchedFile);
        }
    }
}
exports.patchMetroBabelRcRoots = patchMetroBabelRcRoots;
//# sourceMappingURL=patchMetroBabelRcRoots.js.map