"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getYarnLockTopLevelDependencyRe = exports.getYarnLockTopLevelGitDependencyRe = exports.getYarnLockTopLevelRegistryDependencyRe = void 0;
const lodash_1 = __importDefault(require("lodash"));
/**
 * Builds a regular expression matching a top level registry
 * based dependency as recorded by a yarn.lock file.
 * Two groups are captured by this RegEx :
 * - 1: Name of the dependency (as seen in package.json)
 * - 2: Version of the dependency (as seen in package.json)
 *
 * Sample yarn.lock entry:
 * test-miniapp@0.8.3:
 * groups[1] : test-miniapp
 * groups[2] : 0.8.3
 * @param dep The dependency to build a Regular Expression for
 */
function getYarnLockTopLevelRegistryDependencyRe(dep) {
    return new RegExp(`\n(${lodash_1.default.escapeRegExp(dep.basePath)})@(.+):`);
}
exports.getYarnLockTopLevelRegistryDependencyRe = getYarnLockTopLevelRegistryDependencyRe;
/**
 * Builds a regular expression matching a top level git
 * based dependency as recorded by a yarn.lock file.
 * Two groups are captured by this RegEx :
 * - 1: Name of the dependency (as seen in package.json)
 * - 2: Version of the dependency (as seen in package.json)
 *
 * Sample yarn.lock entry:
 * "test-miniapp@https://github.com/org/test-miniapp.git#master":
 * groups[1] : test-miniapp
 * groups[2] : master
 * @param dep The dependency to build a Regular Expression for
 */
function getYarnLockTopLevelGitDependencyRe(dep) {
    return new RegExp(`\n"(.+)@${lodash_1.default.escapeRegExp(dep.basePath)}#(.+)":`);
}
exports.getYarnLockTopLevelGitDependencyRe = getYarnLockTopLevelGitDependencyRe;
function getYarnLockTopLevelDependencyRe(dep) {
    return dep.isGitPath
        ? getYarnLockTopLevelGitDependencyRe(dep)
        : getYarnLockTopLevelRegistryDependencyRe(dep);
}
exports.getYarnLockTopLevelDependencyRe = getYarnLockTopLevelDependencyRe;
//# sourceMappingURL=yarnLockUtils.js.map